<?php
/**
 * NLSClientScript v3.0
 * 
 * CClientScript extension for preventing multiple loading of javascript files.
 * Important! This extension does not prevent to load the same script content from different paths. 
 * So eg. if you published the same js file into different asset directories, this extension won't prevent to load both.
 * 
 * 
 * 
 * Usage: simply set the class for the clientScript component in /protected/config/main.php, like
 *  ...
 *   'components'=>array(
 *     ...
 *     'clientScript' => array('class'=>'your.path.to.NLSClientScript')
 *     ...
 *   )
 *  ...
 * 
 * The extension is based on the great idea of Eirik Hoem, see
 * http://www.eirikhoem.net/blog/2011/08/29/yii-framework-preventing-duplicate-jscss-includes-for-ajax-requests/
 * 
 */
class EClientScript extends CClientScript {

/**
 * Applying global ajax post-filtering
**/
	public function init() {

		parent::init();
		
		if (Yii::app()->request->isAjaxRequest)
			return;
		
		//we need jquery
		$this->registerCoreScript('jquery');

		$this->registerScript('fixDuplicateResources', '

$.ajaxSetup({
	global: true,
	dataFilter: function(data,type) {

		//shortcut: only "text" and "html" dataType should be filtered
		if (type && type != "html" && type != "text")
			return data;

		var selector = "script[src]",tmp,i,res;

		//things to do only first time
		if (!$._resMap) {
			$._resMap = {};
			$._holder = $(document.createElement("div"));

			//fetching scripts from the DOM
			for(i=0,res=$(document).find(selector); i<res.length; i++)
				$._resMap[res[i].src] = 1;
		}

		$._holder[0].innerHTML = data;

		// iterate over new scripts and remove if source is already in DOM:
		for(i=0,res=$._holder.find(selector); i<res.length; i++) {
			tmp = res[i];
			if ($._resMap[tmp.src])
				$(tmp).remove();
			else
				$._resMap[tmp.src] = 1;//adding new script to the cache
		}

		return $._holder[0].innerHTML;
	}
});',	CClientScript::POS_HEAD);
	}
}
